# COMET: Identifying candidate marker panels from single-cell transcriptomic data.

[![Documentation Status](https://readthedocs.org/projects/hgmd/badge/?version=latest)](https://hgmd.readthedocs.io/en/latest/?badge=latest)

## Installation and Usage
  Check out the [COMET documentation](https://hgmd.readthedocs.io/en/latest/)!

## About us

  Actively maintained by Osmaan Shahid (oshahid@ds.dfci.harvard.edu).

  Developed by Conor Delaney (cdelaney@bcb.dfci.harvard.edu).

  Prototyped by Aaron Yao-Smith (aty25@cornell.edu).
  
  Uses the [XL-mHG](https://github.com/flo-compbio/xlmhg) test, created by Florian Wagner.
